@@ -2,6 +2,8 @@
 
 from enum import Enum
 
+from .exceptions import BadResultCodeError
+
 
 class ArmType(Enum):
     AWAY = 0
@@ -14,7 +16,7 @@ class ArmType(Enum):
 class ArmingState(Enum):
     DISARMED = 10200
     DISARMED_BYPASS = 10211
-    DISARMED_ZONE_FAULTED = 10214   # only seems to apply to location, not to partition.  See issue #144
+    DISARMED_ZONE_FAULTED = 10214  # seems to apply to location, not to partition.  See issue #144
 
     ARMED_AWAY = 10201
     ARMED_AWAY_BYPASS = 10202
@@ -48,7 +50,9 @@ class ArmingState(Enum):
 
     def is_disarmed(self):
         """Return True if the system is disarmed."""
-        return self in (ArmingState.DISARMED, ArmingState.DISARMED_BYPASS, ArmingState.DISARMED_ZONE_FAULTED)
+        return self in (
+            ArmingState.DISARMED, ArmingState.DISARMED_BYPASS, ArmingState.DISARMED_ZONE_FAULTED
+        )
 
     def is_armed_away(self):
         """Return True if the system is armed away in any way."""
@@ -80,10 +84,8 @@ class ArmingState(Enum):
     def is_armed(self):
         """Return True if the system is armed in any way."""
         return (
-            self.is_armed_away()
-            or self.is_armed_custom_bypass()
-            or self.is_armed_home()
-            or self.is_armed_night()
+            self.is_armed_away() or self.is_armed_home() or  # noqa: W504
+            self.is_armed_night() or self.is_armed_custom_bypass()
         )
 
     def is_triggered_police(self):
@@ -101,7 +103,39 @@ class ArmingState(Enum):
     def is_triggered(self):
         """Return True if the system is triggered in any way."""
         return (
-            self.is_triggered_fire()
-            or self.is_triggered_gas()
-            or self.is_triggered_police()
+            self.is_triggered_fire() or self.is_triggered_gas() or self.is_triggered_police()
         )
+
+
+class _ResultCode(Enum):
+    """As suggested by the leading underscore, this class is not used by
+    callers of the API.
+    """
+
+    @staticmethod
+    def from_response(response_dict):
+        try:
+            return _ResultCode(response_dict["ResultCode"])
+        except ValueError:
+            raise BadResultCodeError(
+                f"unknown result code {response_dict['ResultCode']}", response_dict
+            ) from None
+
+    SUCCESS = 0
+    ARM_SUCCESS = 4500
+    DISARM_SUCCESS = 4500
+    SESSION_INITIATED = 4500
+
+    BAD_USER_OR_PASSWORD = -50004
+    INVALID_SESSIONID = -30002
+    COMMAND_FAILED = -4502
+    USER_CODE_UNAVAILABLE = -4114
+    USER_CODE_INVALID = -4106
+    FAILED_TO_CONNECT = -4104
+    FEATURE_NOT_SUPPORTED = -120
+    INVALID_SESSION = -102
+    AUTHENTICATION_FAILED = -100
+    CONNECTION_ERROR = 4101
+
+
+PROJECT_URL = "https://github.com/craigjmidwinter/total-connect-client"
